==> limnoria_2022.3.17.orig.tar.gz: limnoria-2022.3.17/plugins/Games/test.py <==
###
# Copyright (c) 2003-2005, Jeremiah Fincher
# Copyright (c) 2010-2021, Valentin Lorentz
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#   * Redistributions of source code must retain the above copyright notice,
#     this list of conditions, and the following disclaimer.
#   * Redistributions in binary form must reproduce the above copyright notice,
#     this list of conditions, and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#   * Neither the name of the author of this software nor the name of
#     contributors to this software may be used to endorse or promote products
#     derived from this software without specific prior written consent.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
###

from supybot.test import *

class GamesTestCase(ChannelPluginTestCase):
    plugins = ('Games',)
    _nonKickRe = re.compile(r'bang|click|spin', re.I)
    def testRoulette(self):
        self.irc.feedMsg(ircmsgs.op(self.channel, self.irc.nick))
        sawKick = False
        for i in range(100):
            m = self.getMsg('roulette', frm='someoneElse!foo@bar')
            if m.command == 'PRIVMSG':
                self.assertTrue(self._nonKickRe.search(m.args[1]),
                                'Got a msg without bang|click|spin: %r' % m)
            elif m.command == 'KICK':
                sawKick = True
                self.assertTrue('bang' in m.args[2].lower(),
                                'Got a KICK without bang in it.')
            else:
                self.fail('Got something other than a kick or a privmsg.')
        self.assertTrue(sawKick, 'Didn\'t get a kick in %s iterations!' % i)

    def testEightball(self):
        self.assertNotError('eightball')
        self.assertNotError('eightball a')
        self.assertNotError('eightball ab')
        self.assertNotError('eightball abc')

# vim:set shiftwidth=4 softtabstop=4 expandtab textwidth=79:

==> limnoria_2025.11.2.orig.tar.gz: limnoria-2025.11.2/plugins/Games/test.py <==
###
# Copyright (c) 2003-2005, Jeremiah Fincher
# Copyright (c) 2010-2021, Valentin Lorentz
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#   * Redistributions of source code must retain the above copyright notice,
#     this list of conditions, and the following disclaimer.
#   * Redistributions in binary form must reproduce the above copyright notice,
#     this list of conditions, and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#   * Neither the name of the author of this software nor the name of
#     contributors to this software may be used to endorse or promote products
#     derived from this software without specific prior written consent.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
###

from supybot.test import *

class GamesTestCase(ChannelPluginTestCase):
    plugins = ('Games',)
    _nonKickRe = re.compile(r'bang|click|spin', re.I)
    def testRoulette(self):
        self.irc.feedMsg(ircmsgs.op(self.channel, self.irc.nick))
        sawKick = False
        for i in range(100):
            m = self.getMsg('roulette', frm='someoneElse!foo@bar')
            if m.command == 'PRIVMSG':
                self.assertTrue(self._nonKickRe.search(m.args[1]),
                                'Got a msg without bang|click|spin: %r' % m)
            elif m.command == 'KICK':
                sawKick = True
                self.assertIn(
                    'bang',
                    m.args[2].lower(),
                    'Got a KICK without bang in it.'
                )
            else:
                self.fail('Got something other than a kick or a privmsg.')
        self.assertTrue(sawKick, 'Didn\'t get a kick in %s iterations!' % i)

    def testEightball(self):
        self.assertNotError('eightball')
        self.assertNotError('eightball a')
        self.assertNotError('eightball ab')
        self.assertNotError('eightball abc')

# vim:set shiftwidth=4 softtabstop=4 expandtab textwidth=79:
